diff --git a/app/frontend/src/components/Controls.vue b/app/frontend/src/components/Controls.vue
index b8eb059..06000a4 100644
--- a/app/frontend/src/components/Controls.vue
+++ b/app/frontend/src/components/Controls.vue
@@ -2,7 +2,7 @@
-
+
diff --git a/server/frontend/app/classes/network.py b/server/frontend/app/classes/network.py
index 825c741..0007a47 100644
--- a/server/frontend/app/classes/network.py
+++ b/server/frontend/app/classes/network.py
@@ -295,9 +295,10 @@ class Network(object):
sp.Popen(["iptables", "-A", "POSTROUTING", "-t", "nat", "-o",
self.iface_out, "-j", "MASQUERADE"]).wait()
# Prevent the device to reach the 80 of TinyCheck.
sp.Popen(["iptables", "-A", "INPUT", "-i", self.iface_in, "-d",
- "192.168.100.1", "-p", "tcp", "--dport", "80", "-j" "DROP"]).wait()
+ "192.168.100.1", "-p", "tcp", "--match", "multiport", "--dports", "80,443", "-j" "DROP"]).wait()
+
return True
except:
return False
@@ -295,9 +295,10 @@ class Network(object):
sp.Popen(["iptables", "-A", "POSTROUTING", "-t", "nat", "-o",
self.iface_out, "-j", "MASQUERADE"]).wait()
- # Prevent the device to reach the 80 of TinyCheck.
+ # Prevent the device to reach the 80 and 443 of TinyCheck.
sp.Popen(["iptables", "-A", "INPUT", "-i", self.iface_in, "-d",